pyxmpp.expdict

Package pyxmpp :: Module expdict |
[hide private]

# Module expdict

source code

Dictionary with item expiration.

Classes | [hide private]
| ExpiringDictionary An extension to standard Python dictionary objects which implements item expiration.

Variables | [hide private]
| __revision__ = ``'``$Id: expdict.py 714 2010-04-05 10:20:10Z jajcu``...``
| sentinel = `object()`
| __package__ = ``'``pyxmpp``'``

Imports: time, threading

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: expdict.py 714 2010-04-05 10:20:10Z jajcus $'